@@ -903,6 +903,8 @@ atk_text_set_caret_offset (AtkText *text,
  * @rect: A pointer to a AtkTextRectangle which is filled in by this function.
  *
  * Get the bounding box for text within the specified range.
+ *
+ * Since: ATK 1.3
  **/
 void
 atk_text_get_range_extents (AtkText          *text,
@@ -935,6 +937,8 @@ atk_text_get_range_extents (AtkText          *text,
  *
  * Get the ranges of text in the specified bounding box.
  *
+ * Since: ATK 1.3
+ *
  * Returns: Array of AtkTextRange. The last element of the array returned 
  *          by this function will be NULL.
  **/
@@ -1019,7 +1023,7 @@ atk_text_attribute_get_name (AtkTextAttribute attr)
 {
   GTypeClass *type_class;
   GEnumValue *value;
-  gchar *name = NULL;
+  const gchar *name = NULL;
 
   type_class = g_type_class_ref (ATK_TYPE_TEXT_ATTRIBUTE);
   g_return_val_if_fail (G_IS_ENUM_CLASS (type_class), NULL);
@@ -1125,10 +1129,10 @@ atk_text_attribute_get_value (AtkTextAttribute attr,
       g_assert (index >= 0 && index < 2);
       return bool[index];
     case ATK_TEXT_ATTR_UNDERLINE:
-      g_assert (index >= 0 && index < 4);
+      g_assert (index >= 0 && index < 5);
       return underline[index];
     case ATK_TEXT_ATTR_WRAP_MODE:
-      g_assert (index >= 0 && index < 3);
+      g_assert (index >= 0 && index < 4);
       return wrap_mode[index];
     case ATK_TEXT_ATTR_DIRECTION:
       g_assert (index >= 0 && index < 3);
@@ -1310,6 +1314,8 @@ atk_text_real_get_bounded_ranges (AtkText          *text,
  * Frees the memory associated with an array of AtkTextRange. It is assumed
  * that the array was returned by the function atk_text_get_bounded_ranges
  * and is NULL terminated.
+ *
+ * Since: ATK 1.3
  **/
 void
 atk_text_free_ranges (AtkTextRange **ranges)
